@@ -33,6 +33,7 @@ class WeixinPayError(WeixinError):
 
 
 class WeixinPay(object):
+    PAY_HOST = "https://api.mch.weixin.qq.com"
 
     def __init__(self, app_id, mch_id, mch_key, notify_url, key=None, cert=None):
         self.app_id = app_id
@@ -111,7 +112,7 @@ class WeixinPay(object):
         app_id, mchid, nonce_str自动填写
         spbill_create_ip 在flask框架下可以自动填写, 非flask框架需要主动传入此参数
         """
-        url = "https://api.mch.weixin.qq.com/pay/unifiedorder"
+        url = self.PAY_HOST + "/pay/unifiedorder"
 
         # 必填参数
         if "out_trade_no" not in data:
@@ -157,7 +158,7 @@ class WeixinPay(object):
         out_trade_no, transaction_id至少填一个
         appid, mchid, nonce_str不需要填入
         """
-        url = "https://api.mch.weixin.qq.com/pay/orderquery"
+        url = self.PAY_HOST + "/pay/orderquery"
 
         if "out_trade_no" not in data and "transaction_id" not in data:
             raise WeixinPayError("订单查询接口中，out_trade_no、transaction_id至少填一个")
@@ -170,7 +171,7 @@ class WeixinPay(object):
         out_trade_no必填
         appid, mchid, nonce_str不需要填入
         """
-        url = "https://api.mch.weixin.qq.com/pay/closeorder"
+        url = self.PAY_HOST + "/pay/closeorder"
 
         data.setdefault("out_trade_no", out_trade_no)
 
@@ -183,9 +184,9 @@ class WeixinPay(object):
         out_refund_no、total_fee、refund_fee、op_user_id为必填参数
         appid、mchid、nonce_str不需要填入
         """
+        url = self.PAY_HOST + "/secapi/pay/refund"
         if not self.key or not self.cert:
             raise WeixinError("退款申请接口需要双向证书")
-        url = "https://api.mch.weixin.qq.com/secapi/pay/refund"
         if "out_trade_no" not in data and "transaction_id" not in data:
             raise WeixinPayError("退款申请接口中，out_trade_no、transaction_id至少填一个")
         if "out_refund_no" not in data:
@@ -206,7 +207,7 @@ class WeixinPay(object):
         out_refund_no、out_trade_no、transaction_id、refund_id四个参数必填一个
         appid、mchid、nonce_str不需要填入
         """
-        url = "https://api.mch.weixin.qq.com/pay/refundquery"
+        url = self.PAY_HOST + "/pay/refundquery"
         if "out_refund_no" not in data and "out_trade_no" not in data \
                 and "transaction_id" not in data and "refund_id" not in data:
             raise WeixinPayError("退款查询接口中，out_refund_no、out_trade_no、transaction_id、refund_id四个参数必填一个")
@@ -219,7 +220,7 @@ class WeixinPay(object):
         bill_date、bill_type为必填参数
         appid、mchid、nonce_str不需要填入
         """
-        url = "https://api.mch.weixin.qq.com/pay/downloadbill"
+        url = self.PAY_HOST + "/pay/downloadbill"
         data.setdefault("bill_date", bill_date)
         data.setdefault("bill_type", bill_type)
 
@@ -227,3 +228,75 @@ class WeixinPay(object):
             raise WeixinPayError("对账单接口中，缺少必填参数bill_date")
 
         return self._fetch(url, data)
+
+    def pay_individual(self, **data):
+        """
+        企业付款到零钱
+        """
+        url = "https://api.mch.weixin.qq.com/mmpaymkttransfers/promotion/transfers"
+        if not self.key or not self.cert:
+            raise WeixinPayError("企业接口需要双向证书")
+        if "partner_trade_no" not in data:
+            raise WeixinPayError("企业付款接口中, 缺少必要的参数partner_trade_no")
+        if "openid" not in data:
+            raise WeixinPayError("企业付款接口中，缺少必填参数openid")
+        if "amount" not in data:
+            raise WeixinPayError("企业付款接口中，缺少必填参数amount")
+        if "desc" not in data:
+            raise WeixinPayError("企业付款接口中，缺少必填参数desc")
+        data.setdefault('check_name', 'NO_CHECK')
+        return self._fetch_pay(url, data, True)
+
+    def pay_individual_to_card(self, **data):
+        """企业付款到银行卡"""
+        url = 'https://api.mch.weixin.qq.com/mmpaysptrans/pay_bank'
+        if not self.key or not self.cert:
+            raise WeixinPayError("企业接口需要双向证书")
+        if "partner_trade_no" not in data:
+            raise WeixinPayError("企业付款接口中, 缺少必要的参数partner_trade_no")
+        if "enc_bank_no" not in data:
+            raise WeixinPayError("企业付款接口中，缺少必填参数enc_bank_no")
+        if "enc_true_name" not in data:
+            raise WeixinPayError("企业付款接口中，缺少必填参数enc_true_name")
+        if "bank_code" not in data:
+            raise WeixinPayError("企业付款接口中，缺少必填参数bank_code")
+        if "amount" not in data:
+            raise WeixinPayError("企业付款接口中，缺少必填参数amount")
+        return self._fetch(url, data, True)
+
+    def pay_individual_bank_query(self, **data):
+        """企业付款到银行卡查询"""
+        url = "https://api.mch.weixin.qq.com/mmpaysptrans/query_bank"
+        if not self.key or not self.cert:
+            raise WeixinPayError("企业接口需要双向证书'")
+        if "partner_trade_no" not in data:
+            raise WeixinPayError("企业付款接口中, 缺少必要的参数partner_trade_no")
+        return self._fetch(url, data, True)
+
+    def pay_individual_query(self, **data):
+        """企业付款到零钱查询"""
+        url = "https://api.mch.weixin.qq.com/mmpaymkttransfers/gettransferinfo"
+        if not self.key or not self.cert:
+            raise WeixinPayError("企业接口需要双向证书'")
+        if "partner_trade_no" not in data:
+            raise WeixinPayError("企业付款接口中, 缺少必要的参数partner_trade_no")
+        return self._fetch(url, data, True)
+
+    def _fetch_pay(self, url, data, use_cert=False):
+        data.setdefault("mch_appid", self.app_id)
+        data.setdefault("mchid", self.mch_id)
+        data.setdefault("nonce_str", self.nonce_str)
+        data.setdefault("sign", self.sign(data))
+        if use_cert:
+            resp = self.sess.post(url, data=self.to_xml(data), cert=(self.cert, self.key))
+        else:
+            resp = self.sess.post(url, data=self.to_xml(data))
+        content = resp.content.decode("utf-8")
+        if "return_code" in content:
+            data = Map(self.to_dict(content))
+            if data.return_code == FAIL:
+                raise WeixinPayError(data.return_msg)
+            if "result_code" in content and data.result_code == FAIL:
+                raise WeixinPayError(data.err_code_des)
+            return data
+        return content
